from django.test import TestCase
try:
    from django.shortcuts import reverse
except:
    from django.core.urlresolvers import reverse


class MobileViewTestCase(TestCase):
    def test_desktop_view(self):
        response = self.client.get(reverse('home'))
        self.assertIn(b'<title>Desktop template</title>', response.content)

    def test_mobile_view(self):
        response = self.client.get(reverse('home'), SERVER_NAME='m.localhost')
        self.assertIn(b'<title>Mobile template</title>', response.content)



import re
from django.conf import settings


class MobileTemplateView(object):
    """
    Change template_name based on domain.
    """
    template_name = NotImplemented

    @staticmethod
    def is_mobile(host):
        """
        Check if domain is matched to regex.

        :param host: hostname.
        :type host: str
        :rtype: bool
        :return: true if domain is mobile.
        """
        if hasattr(settings, 'MOBILE_DOMAIN_REGEX'):
            regex = re.compile(settings.MOBILE_DOMAIN_REGEX)
        else:
            regex = re.compile('^m.\.*.\.*.*')

        if regex.match(host):
            return True
        else:
            return False

    def get_template_names(self):
        """
        Overriding default method to be able change template_name dynamically.

        :rtype: list
        :return: template names list.
        """
        if self.is_mobile(self.request.get_host()):
            if hasattr(settings, 'MOBILE_TEMPLATES_PREFIX'):
                return [settings.MOBILE_TEMPLATES_PREFIX + self.template_name, ]
            else:
                return ['mobile/' + self.template_name, ]

        return [self.template_name]



import os
from setuptools import setup

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

setup(
    name='django-mobile-template',
    version='0.1',
    packages=[
        'mobile_template',
    ],
    include_package_data=True,
    url='https://github.com/linevich/django-mobile-template',
    license='Apache 2.0',
    long_description=README,
    author='Anton Linevych',
    author_email='mail@linevich.net',
    description='Simple app that dynamically changes the templates based on domain/subdomain.',
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
)
